@@ -1,10 +1,6 @@
 #' Retrieve state and county FIPS codes
 #'
-#' @param regions The region breakdown for the map, can be one of
-#'   (\code{"states"}, \code{"state"}, \code{"counties"}, \code{"county"}).
-#'   The default is \code{"states"}.
-#' @param as_sf Defunct, this parameter no longer has any effect and will be removed in
-#'  the future.
+#' @inheritParams us_map
 #'
 #' @return An data frame of FIPS codes of the desired \code{regions}.
 #'
@@ -17,11 +13,12 @@
 #' @export
 fips_data <- function(
   regions = c("states", "state", "counties", "county"),
-  as_sf = TRUE
+  as_sf = TRUE,
+  data_year = NULL
 ) {
   regions <- match.arg(regions)
 
-  map_data <- usmapdata::us_map(regions)
+  map_data <- usmapdata::us_map(regions, data_year = data_year)
   sf::st_geometry(map_data) <- NULL
   map_data
 }
